summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/autolayout/autolayouter.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/autolayout/autolayouter.cpp')
-rw-r--r--umbrello/umbrello/autolayout/autolayouter.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/umbrello/umbrello/autolayout/autolayouter.cpp b/umbrello/umbrello/autolayout/autolayouter.cpp
index f70fd195..caf852b7 100644
--- a/umbrello/umbrello/autolayout/autolayouter.cpp
+++ b/umbrello/umbrello/autolayout/autolayouter.cpp
@@ -11,13 +11,13 @@
* (at your option) any later version. *
* *
***************************************************************************/
-#include "autolayouter.h"
+#include "autotqlayouter.h"
-namespace Autolayout {
+namespace Autotqlayout {
-void Autolayouter::autolayout( UMLView * v )
+void Autotqlayouter::autotqlayout( UMLView * v )
{
setCanvas(v);
setGraph(v);
@@ -25,5 +25,5 @@ void Autolayouter::autolayout( UMLView * v )
updateView(v);
}
-} // end namespace Autolayout
+} // end namespace Autotqlayout